@@ -55,7 +55,11 @@ class TrClient:
         result: TestReport = (yield).get_result()
         if call.when == 'call' or result.outcome == 'skipped':
             if marker := item.get_closest_marker(TR_MARKER_NAME):
-                case_id = int(marker.args[0])
+                case = marker.args[0]
+                if isinstance(case, str):
+                    case = case.replace('c', '').replace('C', '')
+
+                case_id = int(case)
 
                 report = ReportDTO(
                     item.name,
@@ -102,9 +106,7 @@ class TrClient:
         return 'Automated test run ' + current_date
 
     def pytest_testnodedown(self, node, error):
-        """
-        Extend master node results with worker's node results.
-        """
+        """Extend master node results with worker's node results."""
         node_reports = pickle.loads(node.workeroutput[WORKER_RESULTS_KEY])
         self._results.extend(node_reports)
 
@@ -169,8 +171,7 @@ class TrClient:
         return any([x.name == 'parametrize' for x in markers])
 
     def _try_send_passed_reports(self, results: List[ReportDTO]) -> None:
-        """
-        Prepare and send all passed tests only then delete them from the reports list.
+        """Prepare and send all passed tests only then delete them from the reports list.
 
         Args:
             results: All results within node.
