@@ -1,9 +1,10 @@
-from _pytest.config.argparsing import Parser
+import pytest
+from pytest import PytestPluginManager, Parser
 from testrail_api import TestRailAPI
 
 from pytest_testrail_integrator.client import TrClient
-from pytest_testrail_integrator.service import TrService
 from pytest_testrail_integrator.config import TrConfig
+from pytest_testrail_integrator.service import TrService
 
 
 def pytest_addoption(parser: Parser):
@@ -14,14 +15,28 @@ def pytest_addoption(parser: Parser):
         help='Setup TestRail report client for upload test results.'
     )
     group.addoption(
-        '--tr_deselect_tests',
+        '--tr-deselect-tests',
         action='store_true',
         help='Deselect tests if its\' case is not present in run.'
     )
+    group.addoption(
+        '--tr-tb',
+        action='store',
+        help='Sets traceback level in testrail message reports.'
+    )
     parser.addini('tr_url', default='', help='Testrail Api url.')
     parser.addini('tr_user_email', default='', help='Testrail user\'s email.')
     parser.addini('tr_user_password', default='', help='Testrail user\'s password.')
     parser.addini('tr_project_id', default='', help='Testrail project id for new testrun creation.')
+    parser.addini('tr_suite_id', default='', help='Testrail suite id to create test run from.')
+    parser.addini('tr_run_id', default='', help='Testrail run id to update tests in.')
+    parser.addini('tr_tb', default='', help='Sets traceback level in testrail message reports.')
+
+
+@pytest.hookimpl
+def pytest_addhooks(pluginmanager: PytestPluginManager):
+    from pytest_testrail_integrator import new_hooks
+    pluginmanager.add_hookspecs(new_hooks)
 
 
 def pytest_configure(config):
